@@ -1,2 +1,2 @@
 BASE_URL = 'radoneyestationv2-api.azurewebsites.net/api'
-LOCAL_URL = ''
+SUPPORTED_INTERFACES = ['eth0', 'enp0s3', 'wlan0']
